@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: __init__.py 10719 2018-01-07 08:03:23Z Lavender $
+# $Id: __init__.py 10957 2018-04-02 08:31:56Z Lavender $
 #
 # Copyright (c) 2015 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: Lavender $ (last)
-# $Date: 2018-01-07 16:03:23 +0800 (週日, 07 一月 2018) $
-# $Revision: 10719 $
+# $Date: 2018-04-02 16:31:56 +0800 (週一, 02 四月 2018) $
+# $Revision: 10957 $
 
 import os
 import warnings
@@ -84,6 +84,7 @@ def attachSettings(settingsDict):
         'Zephyrus.facebook',
         'drip',
         'Zephyrus.autoresponder',
+        'Zephyrus.comment',
     )
 
     installed = settingsDict['INSTALLED_APPS']
@@ -119,7 +120,7 @@ def attachSettings(settingsDict):
                 ['TextColor', 'BGColor'],
                 ['Maximize', 'ShowBlocks', '-', 'About'],
             ],
-            'skin': 'moono',
+            'skin': 'moono-lisa',
         },
         'TEXT_ADDITIONAL_TAGS': (
             'iframe',
