@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: __init__.py 10825 2018-03-11 13:34:27Z Lavender $
+# $Id: __init__.py 10864 2018-03-18 08:28:24Z Lavender $
 #
 # Copyright (c) 2017 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,11 +12,12 @@
 # limitations under the License.
 #
 # $Author: Lavender $
-# $Date: 2018-03-11 21:34:27 +0800 (週日, 11 三月 2018) $
-# $Revision: 10825 $
+# $Date: 2018-03-18 16:28:24 +0800 (週日, 18 三月 2018) $
+# $Revision: 10864 $
 
 import os
 import logging
+import platform
 
 from django.conf import settings
 
@@ -55,7 +56,17 @@ PROJECT_VIRTUALENV_DIR = os.path.join(
     ROOT_DIR_PATH, "ZephyrusEnv")
 
 PROJECT_MASHINES_ZIP = os.path.join(
-    os.path.dirname(os.path.abspath(__file__)), "ProjectMachine[VERSION].zip")
+    os.path.dirname(os.path.abspath(__file__)), "ProjectMachine_[VERSION].zip")
+
+PROJECT_ENV_REQUIREMENTS = os.path.join(
+    os.path.dirname(os.path.abspath(__file__)), "REQUIREMENTS_[VERSION].txt")
+
+if 'Windows' in platform.system(): 
+    PROJECT_ENV_SCRIPT = os.path.join(
+        os.path.dirname(os.path.abspath(__file__)), "CreateEnv.bat")
+else:
+    PROJECT_ENV_SCRIPT = os.path.join(
+        os.path.dirname(os.path.abspath(__file__)), "CreateEnv.sh")
 
 def createLogger(name, fileHandlerName):
     logger = logging.getLogger(name)
