@@ -85,10 +85,16 @@ class Command(BaseCommand):
                 # endprocess
                 text = text.replace(
                     loadTagHash, 
-                    "{% load cms_tags menu_tags sekizai_tags staticfiles %}")
-                text = text.replace(jsHash, "{% render_block 'js' %}")
-                text = text.replace(cssHash, "{% render_block 'css' %}")
-                text = text.replace(toolbarHash, "{% cms_toolbar %}")
+                    ("{% load cms_tags menu_tags sekizai_tags staticfiles %}"
+                     "{% with '' as CMS_STATIC_DIR %}"))
+                text = text.replace(
+                    jsHash, "{% endwith %}{% render_block 'js' %}")
+                text = text.replace(
+                    cssHash, "{% endwith %}{% render_block 'css' %}")
+                text = text.replace(
+                    toolbarHash, 
+                    ("{% cms_toolbar %}"
+                     "{% with '' as CMS_STATIC_DIR %}"))
                 with open(fileName, 'wb') as f:
                     f.write(text.encode('utf8'))
         except Exception as e:
