@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: pluginize.py 10720 2018-01-07 08:53:37Z Lavender $
+# $Id: pluginize.py 10966 2018-04-03 08:16:27Z Lavender $
 #
 # Copyright (c) 2015 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: Lavender $
-# $Date: 2018-01-07 16:53:37 +0800 (週日, 07 一月 2018) $
-# $Revision: 10720 $
+# $Date: 2018-04-03 16:16:27 +0800 (週二, 03 四月 2018) $
+# $Revision: 10966 $
 
 import os
 import json
@@ -23,6 +23,8 @@ import hashlib
 import traceback
 import re
 
+import cms
+
 from django.core.management.base import BaseCommand, CommandError
 from django.core.management import call_command
 from django.test.client import RequestFactory
@@ -36,6 +38,7 @@ from djangocms_text_ckeditor.cms_plugins import TextPlugin
 from cms.templatetags.cms_tags import *
 from filer.models.filemodels import File
 from cms.models.pagemodel import Page
+from cms.models.pluginmodel import CMSPlugin
 from lxml.html import fromstring
 from html5lib import sanitizer
 from html5lib.filters import sanitizer as filtersSanitizer
@@ -125,6 +128,7 @@ class Placeholder2(Placeholder):
         from cms.models.pluginmodel import CMSPlugin
         from djangocms_text_ckeditor.models import Text
         from cmsplugin_filer_image.models import FilerImage
+        from djangocms_picture.models import Picture
 
         placeholders = Placeholder.objects.filter(slot=name)
 
@@ -144,13 +148,10 @@ class Placeholder2(Placeholder):
         
         for placeholder in placeholders:
             # logger.info("id: %s, name: %s" % (placeholder.id, placeholder.slot))
-            hasTextPlugin = Text.objects.filter(
-                                    placeholder=placeholder, position=0
-                            ).exists()
-            hasImgPlugin = FilerImage.objects.filter(
+            hasPlugin = CMSPlugin.objects.filter(
                                         placeholder=placeholder).exists()
 
-            if not hasTextPlugin and not hasImgPlugin:
+            if not hasPlugin:
                 string = content.lower().strip()
                 
                 isOutSideTag = False
@@ -179,11 +180,13 @@ class Placeholder2(Placeholder):
                         img = root.getchildren()[0]
                         # add a attrs
                         attrList = []
+                        aAttrDict = {}
                         attrs = root.items()
                         for k, v in attrs:
                             if k == 'href':
                                 continue
                             attrList.append(Attr(k, v))
+                            aAttrDict[k] = v
                         
                         
                         tagList.append(
@@ -204,33 +207,57 @@ class Placeholder2(Placeholder):
 
                     # add img attrs
                     attrList = []
+                    imgAttrDict = {}
                     attrs = img.items()
                     for k, v in attrs:
                         if k == 'src':
                             continue
                         attrList.append(Attr(k, v))
+                        imgAttrDict[k] = v
                     
                     
                     tagList.append(
                         Tag('img', placeholder.slot, 
                         hashlib.md5(placeholder.slot).hexdigest(), attrList))
                     
-                    
-                    if root.tag == 'a':
-                        link = root.get('href')
-                        FilerImage.objects.create(
-                            placeholder=placeholder,
-                            language=Placeholder2.lang,
-                            caption_text='', image_url=url,
-                            plugin_type='FilerImagePlugin',
-                            free_link=link)
-
+                    if cms.__version__.startswith('3.5'):
+                        if root.tag == 'a':
+                            link = root.get('href')
+                            if link == '' or link == None:
+                                link = '#'
+                            Picture.objects.create(
+                                placeholder=placeholder,
+                                language=Placeholder2.lang,
+                                plugin_type='PicturePlugin',
+                                link_url=link,
+                                external_picture=url,
+                                attributes=imgAttrDict,
+                                link_attributes=aAttrDict,
+                            )                    
+                        else:
+                            Picture.objects.create(
+                                placeholder=placeholder,
+                                language=Placeholder2.lang,
+                                plugin_type='PicturePlugin',
+                                external_picture=url,
+                                attributes=imgAttrDict,
+                            )                    
                     else:
-                        FilerImage.objects.create(
-                            placeholder=placeholder,
-                            language=Placeholder2.lang,
-                            caption_text='', image_url=url,
-                            plugin_type='FilerImagePlugin',)
+                        if root.tag == 'a':
+                            link = root.get('href')
+                            FilerImage.objects.create(
+                                placeholder=placeholder,
+                                language=Placeholder2.lang,
+                                caption_text='', image_url=url,
+                                plugin_type='FilerImagePlugin',
+                                free_link=link)
+
+                        else:
+                            FilerImage.objects.create(
+                                placeholder=placeholder,
+                                language=Placeholder2.lang,
+                                caption_text='', image_url=url,
+                                plugin_type='FilerImagePlugin',)
                     
                 else:
                     textPlugin = Text.objects.create(
@@ -246,6 +273,12 @@ class Command(BaseCommand):
     # Validation is called explicitly each time the server is reloaded.
     requires_model_validation = False
     
+    def add_arguments(self, parser):
+        parser.add_argument(
+                '-t', '--template', 
+                type=str,
+                help="template name.")
+    
     def handle(self, language='', *args, **options):
         try:
             from django import template
@@ -290,6 +323,9 @@ class Command(BaseCommand):
             @transaction.atomic
             def process():
                 for file in os.listdir(path):
+                    if options['template']:
+                        if not file == options['template']:
+                            continue
                     file = os.path.join(path, file)
                     
                     result = os.path.splitext(file)[-1]
@@ -326,13 +362,14 @@ class Command(BaseCommand):
                 f.write(content)
 
             # build CMSContext.js
-            temp = get_template('boilerplate/js/CMSContext.js')
-            replaceStr = Context({
-                'tagList': newTagList, 
-            })
-            content = temp.render(replaceStr)
-            with open(contextPath, 'w') as f:
-                f.write(content)
+            if not cms.__version__.startswith('3.5'):
+                temp = get_template('boilerplate/js/CMSContext.js')
+                replaceStr = Context({
+                    'tagList': newTagList, 
+                })
+                content = temp.render(replaceStr)
+                with open(contextPath, 'w') as f:
+                    f.write(content)
 
             if os.path.isfile(os.path.join(ROOT_DIR_PATH, 'info.json')):
                 with open(os.path.join(ROOT_DIR_PATH, 'info.json')) as jsonfile:
