@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: setup.py 10826 2018-03-11 14:13:24Z Lavender $
+# $Id: setup.py 10962 2018-04-03 06:45:05Z Lavender $
 #
 # Copyright (c) 2017 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: Lavender $
-# $Date: 2018-03-11 22:13:24 +0800 (週日, 11 三月 2018) $
-# $Revision: 10826 $
+# $Date: 2018-04-03 14:45:05 +0800 (週二, 03 四月 2018) $
+# $Revision: 10962 $
 import os
 import sys
 import logging
@@ -197,11 +197,7 @@ else:
         import cms
     
         if cms.__version__.startswith('3.5'):
-            pluginList = [
-                    'cmsplugin_filer_file',
-                    'cmsplugin_filer_folder',
-                    'cmsplugin_filer_image',
-            ]
+            pluginList = []
         else:
             pluginList = []
         
@@ -289,10 +285,13 @@ if __name__ == "__main__":
     wizard = args.wizard
     mode = 'user'
     
-    with open(os.path.join(SETUP_DIR, 'MANIFAST.INFO')) as f:
-        data = json.loads(f.read())
-        
-    cmsVersion = data["DjangoCMSVersion"]
+    if os.path.isfile(os.path.join(SETUP_DIR, 'MANIFAST.INFO')):
+        with open(os.path.join(SETUP_DIR, 'MANIFAST.INFO')) as f:
+            data = json.loads(f.read())
+            
+        cmsVersion = data["DjangoCMSVersion"]
+    else:
+        cmsVersion = '3.5.1'
     
     if cmsVersion.startswith("3.4"):
         installVersion = "0.9.7"
